@@ -1,26 +1,26 @@
-from dynabuffers.ast.AbstractAST import AbstractAST
+from dynabuffers.api.ISerializable import ISerializable
 from dynabuffers.ast.datatype.ByteType import ByteType
 
 
 class ArrayTypeOptions:
-    def __init__(self, datatype:AbstractAST):
+    def __init__(self, datatype:ISerializable):
         self.datatype = datatype
 
-class ArrayType(AbstractAST):
+class ArrayType(ISerializable):
 
     def __init__(self, options):
         self.options = options
 
     def size(self, value, registry):
-        return 2 + (len(value) * self.options.datatype.size(value, registry))
+        return 4 + (len(value) * self.options.datatype.size(value, registry))
 
     def serialize(self, value, buffer, registry):
-        buffer.putShort(len(value))
+        buffer.putInt(len(value))
         for entry in value:
             self.options.datatype.serialize(entry, buffer, registry)
 
     def deserialize(self, buffer, registry):
-        length = buffer.getShort()
+        length = buffer.getInt()
         array = []
 
         for i in range(length):
