@@ -1,4 +1,4 @@
-from dynabuffers.ast.AbstractAST import AbstractAST
+from dynabuffers.api.ISerializable import ISerializable
 
 
 class StringTypeOptions:
@@ -6,19 +6,20 @@ class StringTypeOptions:
         self.charset = charset
 
 
-class StringType(AbstractAST):
+class StringType(ISerializable):
     def __init__(self, options: StringTypeOptions):
         self.options = options
 
     def size(self, value, registry):
-        return 2 + len(str(value).encode(self.options.charset))
+        return 4 + len(str(value).encode(self.options.charset))
 
     def serialize(self, value, buffer, registry):
-        buffer.putShort(len(value))
-        buffer.put(value.encode(self.options.charset))
+        encoded = value.encode(self.options.charset)
+        buffer.putInt(len(encoded))
+        buffer.put(encoded)
 
     def deserialize(self, buffer, registry):
-        length = buffer.getShort()
+        length = buffer.getInt()
         array = buffer.get(length)
 
         return array.decode(self.options.charset)
